#radical.pilot

**Documentation:** http://radicalpilot.readthedocs.org/en/latest/

**Mailinglists:** 

* radical-pilot-users@googlegroups.com
* radical-pilot-devel@googlegroups.com

The `master` branch generally reflects the RADICAL-Pilot release on Pypi, and is
considered stable: it should work 'out of the box' for the supported backends.
For a list of supported backends, please refer to the documentation.

The `devel` branch (and any other branches than master, for that matter)
may not correspond to the publised documentation, and specifically may have
dependencies which need to be resolved manually.  Please contact us over the
mailing list if you need advice on the usage of any non-master branch.

